local harbour = ...

--------------------------------------------------------------------------
-- Apply building asset processor
harbour:registerAssetProcessor("models/lightTower.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register LargeGate prefab nodes
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_0_Light_RootPart", HarbourPrefix .. "_LIGHT_TOWER_ROOT_PREFAB")
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_1_Light_Tiling1Part", HarbourPrefix .. "_LIGHT_TOWER_TILING1_PREFAB")
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_2_Light_Tiling2Part", HarbourPrefix .. "_LIGHT_TOWER_TILING2_PREFAB")
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_3_Light_TopPart", HarbourPrefix .. "_LIGHT_TOWER_TOP_PREFAB")
--------------------------------------------------------------------------

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	harbour:registerAsset({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*1 }
		    },
		    ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _NoSandbox*2 }
		    }}
	        },
	        EstateSplendor = {
		    { Estate = "KINGDOM", Quantity = 0.1 }
	        }
	})
end

local defaultNodePrefixList = {
	HarbourPrefix .. "_LIGHT_TOWER_TOP",
	HarbourPrefix .. "_LIGHT_TOWER_TILING1",
	HarbourPrefix .. "_LIGHT_TOWER_TILING2"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

-- Register the light tower root part
harbour:registerAsset({
	DataType = "BUILDING_PART",
	Id = HarbourPrefix .. "_LIGHT_TOWER_ROOT_PART",
	Name = HarbourPrefix .. "_LIGHT_TOWER_ROOT_NAME",
	Description = HarbourPrefix .. "_LIGHT_TOWER_ROOT_DESC",
	Category = "CORE",
        BuildingZone = _LightTowerBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = HarbourPrefix .. "_LIGHT_TOWER_ROOT_PREFAB",
		EndPart = HarbourPrefix .. "_LIGHT_TOWER_TOP_PART",
		FillerList = {
			HarbourPrefix .. "_LIGHT_TOWER_TILING2_PART"
                },
		BasementFillerList = {
			HarbourPrefix .. "_LIGHT_TOWER_TILING1_PART"
         	},
		MinimumScale = 0,
		IsVertical = true,
                MiniatureConfig = {
                        DataType = "BUILDING_MINIATURE_CONFIG",
                        ClipUnderGround = false
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _NoSandbox*2 }
		}}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	},
        VillagerCapacity = 9
})

--------------------------------------------------------------------------
-- Register grass clearing components

harbour:registerPrefabComponent("models/lightTower.fbx/Prefab/lightTower/step_0_Light_RootPart", {
	DataType = "COMP_DIRT_CIRCLE",
	HardRadius = 4,
        SoftRadius = 4,
        IsPermanent = true
})

-- Register Roof materials
harbour:registerAssetId("models/lightTower.fbx/Materials/redRoof", HarbourPrefix .. "_RED_ROOF_MATERIAL")
harbour:registerAssetId("models/lightTower.fbx/Materials/blueRoof", HarbourPrefix .. "_BLUE_ROOF_MATERIAL")
harbour:registerAssetId("models/lightTower.fbx/Materials/brownRoof", HarbourPrefix .. "_BROWN_ROOF_MATERIAL")
harbour:registerAssetId("models/lightTower.fbx/Materials/greyRoof", HarbourPrefix .. "_GREY_ROOF_MATERIAL")
harbour:registerAssetId("models/lightTower.fbx/Materials/grey2Roof", HarbourPrefix .. "_GREY2_ROOF_MATERIAL")

function registerRoofPart(_nameFbx, _nameAsset)
    harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/" .. _nameFbx .. "Part", HarbourPrefix .. "_" .. _nameAsset .. "_PREFAB")

-- Register the stone gate set decoration roof part
    harbour:registerAsset({
	DataType = "BUILDING_PART",
	Id = HarbourPrefix .. "_" .. _nameAsset .. "_PART",
	Name = HarbourPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = HarbourPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = HarbourPrefix .. "_" .. _nameAsset .. "_PREFAB",
                MiniatureConfig = {
                    ClipUnderGround = false,
                    GroupHeight = 0.0,
                    CameraPosition = { 0, 0, -10 },
                    OrientationOffset = 0,
                    CameraPitchOffset = 0
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _NoSandbox*5 }
		}}
	}
    })

    harbour:registerPrefabComponent("models/lightTower.fbx/Prefab/lightTower/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR" -- Snaps the decoration only on minor attach nodes (here only on the roofs)
    })
end

registerRoofPart( "LightRoofA", "LIGHT_ROOF_A" )

-- Register the boat part
-- Apply building asset processor
harbour:registerAssetProcessor("models/boat.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

    local HARBOUR_CORE_WORKPLACE = {
        TypeName = "HARBOUR_CORE_WORKPLACE",
        ParentType= "BUILDING_FUNCTION_WORKPLACE",
	Properties = {
 		{ Name = "MinimalSailors", Type = "integer", Default = 1},
 		{ Name = "RowingAnimation", Type = "boolean", Default = false},
 		{ Name = "SailingAnimation", Type = "boolean", Default = true},
 		{ Name = "FlagTerrain", Type = "integer", Default = 2 ^ OBJECT_FLAG.TERRAIN:toNumber(), --[[ + 2 ^ OBJECT_FLAG.HARBOUR_WATER_BUILDING:toNumber(), -- + 2 ^ OBJECT_FLAG.PLATFORM:toNumber()--]]},
                { Name = "BoatSpeed", Type = "float", Default = 2.0 },
                { Name = "BoatRotationSpeed", Type = "float", Default = 0.2 },
                { Name = "BoatLength", Type = "float", Default = 10.0 },
                { Name = "BoatLengthRotationMarge", Type = "float", Default = 6.0 },
                { Name = "BoatSmoothRotation", Type = "boolean", Default = false },
                { Name = "RandomPath", Type = "boolean", Default = true },
                { Name = "MaxRandomDistanceMove", Type = "float", Default = 50.0 },
                { Name = "_onEnabledNumber", Type = "integer", Default = 0 },
                { Name = "FirstBoatInitialPosition", Type = "boolean", Default = true },
                { Name = "BoatInitialPosition", Type = "vec3f" },
                { Name = "BoatInitialOrientation", Type = "quaternion" },
                { Name = "IsSailorAssigned", Type = "boolean", Default = false },
                { Name = "IsInitDone", Type = "boolean", Default = false },
                { Name = "goBackToHarbourConditionInit", Type = "integer", Default = 80 },
                { Name = "_stateSequenceNumber", Type = "integer", Default = StateLaunching },
                { Name = "_timer", Type = "float", Default = 10 },
                { Name = "_errorCount", Type = "integer", Default = 0 },
                { Name = "_checkSailorStuckState", Type = "integer", Default = 0 },
                { Name = "_checkSailorStuckTimer", Type = "float", Default = 1 },
       	}
    }
    function HARBOUR_CORE_WORKPLACE:activateBuilding(gameObject)
        harbour:log("HARBOUR_CORE_WORKPLACE:activateBuilding")
        if (gameObject == nil) then
            harbour:log("HARBOUR_CORE_WORKPLACE:activateBuilding gameObject == nil")
            return false
        end
        local comp = gameObject:getOrCreateComponent(HarbourPrefix .. "_COMP_BOAT")
        if (comp  == nil) then
            harbour:log("HARBOUR_CORE_WORKPLACE:activateBuilding comp == nil")
            return false
        end
        harbour:log("HARBOUR_CORE_WORKPLACE:activateBuilding comp = " .. tostring(comp))
        comp:setWorkplaceData(self)
	comp.MinimalSailors               = self.MinimalSailors
 	comp.RowingAnimation              = self.RowingAnimation
 	comp.SailingAnimation             = self.SailingAnimation
 	comp.FlagTerrain                  = self.FlagTerrain
        comp.BoatSpeed                    = self.BoatSpeed
        comp.BoatRotationSpeed            = self.BoatRotationSpeed
        comp.BoatLength                   = self.BoatLength
        comp.BoatLengthRotationMarge      = self.BoatLengthRotationMarge
        comp.BoatSmoothRotation           = self.BoatSmoothRotation
        comp.RandomPath                   = self.RandomPath
        comp.MaxRandomDistanceMove        = self.MaxRandomDistanceMove
        comp._onEnabledNumber             = self._onEnabledNumber
        comp.FirstBoatInitialPosition     = self.FirstBoatInitialPosition
        comp.BoatInitialPosition          = self.BoatInitialPosition
        comp.BoatInitialOrientation       = self.BoatInitialOrientation
        comp.IsSailorAssigned             = self.IsSailorAssigned
        comp.IsInitDone                   = self.IsInitDone
        comp.goBackToHarbourConditionInit = self.goBackToHarbourConditionInit
        comp._stateSequenceNumber         = self._stateSequenceNumber
        comp._timer                       = self._timer
        comp._errorCount                  = self._errorCount
        comp._checkSailorStuckState       = self._checkSailorStuckState
        comp._checkSailorStuckTimer       = self._checkSailorStuckTimer

        comp:init()
        harbour:log("HARBOUR_CORE_WORKPLACE:activateBuilding return true")
        return true
    end
    function HARBOUR_CORE_WORKPLACE:reloadBuildingFunction(gameObject)
        harbour:log("HARBOUR_CORE_WORKPLACE:reloadBuildingFunction")
        self:activateBuilding(gameObject)
    end
    function HARBOUR_CORE_WORKPLACE:removeBuildingFunction(gameObject)
        harbour:log("HARBOUR_CORE_WORKPLACE:removeBuildingFunction")
        local comp = gameObject:getComponent(HarbourPrefix .. "_COMP_BOAT")
        gameObject:removeComponent(comp)
    end
    harbour:registerClass(HARBOUR_CORE_WORKPLACE)

    _optionFunction = "HARBOUR_CORE_WORKPLACE"
    if (_optionComp == "COMPONENT") then
        _optionFunction = "BUILDING_FUNCTION_WORKPLACE"
    end

    local HARBOUR_COMP_WORKPLACE = {
        TypeName = "HARBOUR_COMP_WORKPLACE",
        ParentType= "COMP_WORKPLACE",
	Properties = {
        },
    }
    harbour:registerClass(HARBOUR_COMP_WORKPLACE)

function registerBoat(_namePart, _assetId, _behaviorWork, _capacity)
    -- Register IDs for all prefab nodes referenced here
    harbour:registerAssetId("models/boat.fbx/Prefab/harbour/" .. _namePart, HarbourPrefix .. "_" .. _assetId .. "_PREFAB")

    harbour:registerAsset({
	DataType = "BUILDING_PART",
	Id = HarbourPrefix .. "_" .. _assetId .. "_PART",
	Name = HarbourPrefix .. "_" .. _assetId .. "_NAME",
	Description = HarbourPrefix .. "_" .. _assetId .. "_DESC",
	Category = "DECORATION",
        BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {12, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {12, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
        }},
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = HarbourPrefix .. "_" .. _assetId .. "_PREFAB",
                MiniatureConfig = {
                    ClipUnderGround = false,
                    GroupHeight = 0.0,
                    CameraPosition = { 1, 3, -25 },
                    OrientationOffset = 0,
                    CameraPitchOffset = 10
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*1 }
		},
		ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = _NoSandbox*5 }
		}}
	},
	AssetBuildingFunction = HarbourPrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION"
    })

-- Function list
    harbour:registerAsset({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = HarbourPrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
                AssetFunctionList = {
                        HarbourPrefix .. "_FUNCTION_CORE_" .. _assetId,
                }
    })

    harbour:registerAsset({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = HarbourPrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = HarbourPrefix .. "_" .. _assetId .. "_FUNCTION_LIST"
    })

    harbour:registerAsset({
		DataType = _optionFunction,
                Id = HarbourPrefix .. "_FUNCTION_CORE_" .. _assetId,
                Name = HarbourPrefix .. "_FUNCTION_CORE_" .. _assetId .. "_NAME",
		WorkerCapacity = _capacity,
                RelatedJob = { Job = HarbourPrefix .. "_SAILOR", Behavior = _behaviorWork },
    })

    function registerTradingRoute(_input, _output)
        harbour:registerAsset({
		DataType = _optionFunction,
                Id = HarbourPrefix .. "_FUNCTION_" .. _input[1] .. "_" .. _output[1] .. "_" .. _assetId,
                Name = HarbourPrefix .. "_FUNCTION_" .. _input[1] .. "_" .. _output[1] .. "_" .. _assetId .. "_NAME",
		WorkerCapacity = _capacity,
                RelatedJob = { Job = HarbourPrefix .. "_SAILOR", Behavior = _behaviorWork },
                InputInventoryCapacity = {
			{ Resource = _input[1], Quantity = _input[2]*_capacity }
                },
                ResourceListNeeded = {
			{ Resource = _input[1], Quantity = _input[2] }
                },
                ResourceProduced = {
			{ Resource = _output[1], Quantity = _output[2] }
                }
        })
        harbour:overrideAsset({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = HarbourPrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
                AssetFunctionList = {
                            Action = "APPEND",
                            HarbourPrefix .. "_FUNCTION_" .. _input[1] .. "_" .. _output[1] .. "_" .. _assetId,
                }
        })
    end
    if _behaviorWork == HarbourPrefix .. "_BEHAVIOR_TREE" then
        registerTradingRoute({"GOLD_COINS", _NoSandbox*500}, {"MARBLE", 50})
        registerTradingRoute({"GOLD_COINS", _NoSandbox*250}, {"QUARTZ", 50})
        registerTradingRoute({"GOLD_COINS", _NoSandbox*100}, {"IRON_ORE", 50})
        registerTradingRoute({"GOLD_COINS", _NoSandbox*1500}, {"GOLD_ORE", 50})
        if checkVersion(harbour, "harbour", "Common Resources", "76daffe0-725f-4dac-b1b5-de331dfca67a", "1.2.0") then
            registerTradingRoute({"GOLD_COINS", _NoSandbox*1000}, {"BV1_SUGAR", 50})
            registerTradingRoute({"GOLD_COINS", _NoSandbox*250}, {"BV1_SALT", 50})
        end

        registerTradingRoute({"MARBLE", 50}, {"GOLD_COINS", 500} )
        registerTradingRoute({"QUARTZ", 50}, {"GOLD_COINS", 250} )
        registerTradingRoute({"IRON_ORE", 50}, {"GOLD_COINS", 100} )
        registerTradingRoute({"GOLD_ORE", 50}, {"GOLD_COINS", 1500} )
        if checkVersion(harbour, "harbour", "Common Resources", "76daffe0-725f-4dac-b1b5-de331dfca67a", "1.2.0") then
            registerTradingRoute({"BV1_SUGAR", 50}, {"GOLD_COINS", 1000} )
            registerTradingRoute({"BV1_SALT", 50}, {"GOLD_COINS", 250} )
        end

    end
end

registerBoat("boatStaticPart", "BOAT_STATIC", "BEHAVIOR_WORK", 1)

function registerCompBoat(_namePart, _assetId, _capacity, _sailingAnimation, _rowingAnimation, _goBackToHarbourConditionInit)
    registerBoat(_namePart, _assetId, HarbourPrefix .. "_BEHAVIOR_TREE", _capacity )
    harbour:registerAssetId("models/boat.fbx/Prefab/harbour/" .. _namePart .. "/bateau", HarbourPrefix .. "_" .. _assetId .. "_BATEAU_PREFAB")

if (_optionComp == "COMPONENT") then
    -- Register boat component
    harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/" .. _namePart .. "/bateau", {
	DataType = HarbourPrefix .. "_COMP_BOAT",
        RandomPath = true,
        -- TODO: manage the collision between 2 boats
 	FlagTerrain = 2 ^ OBJECT_FLAG.TERRAIN:toNumber(), -- + 2 ^ OBJECT_FLAG.HARBOUR_WATER_BUILDING:toNumber(), -- + 2 ^ OBJECT_FLAG.PLATFORM:toNumber()
        MinimalSailors = _capacity,
        SailingAnimation = _sailingAnimation,
        RowingAnimation = _rowingAnimation,
        goBackToHarbourConditionInit = _goBackToHarbourConditionInit,
	Enabled = true -- hope the COMP_BOAT will be always enabled, even with worker out of workplace
    })
end
    for i=1,_capacity do
        harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/" .. _namePart .. "/bateau/guardLocator" .. i, {
	    DataType = HarbourPrefix .. "_COMP_GUARDING_LOCATION" .. i,
	    Enabled = false
        })
    end
    harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/" .. _namePart, {
	DataType = "COMP_GROUNDED",
	GroundToWater = true
    })

--    harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/" .. _namePart, {
--	DataType = "HARBOUR_COMP_WORKPLACE",
--    })

end

registerCompBoat("boatPart", "BOAT", 1, true, false, 80)
registerCompBoat("rowingPart", "ROWING", 2, false, true, 60)

if (_optionComp == "COMPONENT") then

-- Register sail component
harbour:registerAssetId("models/boat.fbx/Prefab/harbour/boatPart/bateau/voile", HarbourPrefix .. "_BOAT_VOILE_PREFAB")
harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/boatPart/bateau/voile", {
	DataType = HarbourPrefix .. "_COMP_SAIL",
        SailScaleFactor = 4.0,
	Enabled = false
})
harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/boatPart", {
	    DataType = "COMP_BUILDING_PART",
	    FeedbackComponentListToActivate = {
		{ HarbourPrefix .. "_BOAT_BATEAU_PREFAB", HarbourPrefix .. "_COMP_BOAT" },
		{ HarbourPrefix .. "_BOAT_VOILE_PREFAB", HarbourPrefix .. "_COMP_SAIL" }
	    }
})

-- Register Oar component
harbour:registerAssetId("models/boat.fbx/Prefab/harbour/rowingPart/bateau/oars1", HarbourPrefix .. "_ROWING_OARS1_PREFAB")
harbour:registerAssetId("models/boat.fbx/Prefab/harbour/rowingPart/bateau/oars2", HarbourPrefix .. "_ROWING_OARS2_PREFAB")
harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/rowingPart/bateau/oars1", {
	DataType = HarbourPrefix .. "_COMP_OAR",
	Enabled = false
})
harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/rowingPart/bateau/oars2", {
	DataType = HarbourPrefix .. "_COMP_OAR",
	Enabled = false
})
harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/rowingPart", {
	    DataType = "COMP_BUILDING_PART",
	    FeedbackComponentListToActivate = {
		{ HarbourPrefix .. "_ROWING_BATEAU_PREFAB", HarbourPrefix .. "_COMP_BOAT" },
		{ HarbourPrefix .. "_ROWING_OARS1_PREFAB", HarbourPrefix .. "_COMP_OAR" },
		{ HarbourPrefix .. "_ROWING_OARS2_PREFAB", HarbourPrefix .. "_COMP_OAR" }
	    }
})
end
-- Register static boat component
harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/boatStaticPart", {
	DataType = HarbourPrefix .. "_COMP_STATIC_BOAT",
	Enabled = true
})
harbour:registerPrefabComponent("models/boat.fbx/Prefab/harbour/boatStaticPart", {
	DataType = "COMP_GROUNDED",
	GroundToWater = true
})

-- Register the dock part
-- Apply building asset processor
harbour:registerAssetProcessor("models/dock.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

function registerDockPart(_nameFbx, _nameAsset, _plankQuantity, _buildingZone, _category)

    harbour:registerAssetId("models/dock.fbx/Prefab/harbour/" .. _nameFbx .. "Part", HarbourPrefix .. "_" .. _nameAsset .. "_PREFAB")

    harbour:registerAsset({
	DataType = "BUILDING_PART",
	Id = HarbourPrefix .. "_" .. _nameAsset .. "_PART",
	Name = HarbourPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = HarbourPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = _category,
        BuildingZone = _buildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = HarbourPrefix .. "_" .. _nameAsset .. "_PREFAB",
                MiniatureConfig = {
                    ClipUnderGround = false,
                    GroupHeight = 0.0,
                    CameraPosition = { 0, -1, -40 },
                    OrientationOffset = 0,
                    CameraPitchOffset = 10
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = _NoSandbox*_plankQuantity }
		}}
	}
    })

    harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/" .. _nameFbx .. "Part", {
	DataType = "COMP_GROUNDED",
	GroundToWater = true
    })
end

registerDockPart("dock", "DOCK", 5, _DockBuildingZone, "DECORATION")
registerDockPart("ponton", "PONTOON", 3, _PontonBuildingZone, "DECORATION")
registerDockPart("ramp", "RAMP", 2, _RampBuildingZone, "DOOR")

harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/rampPart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "DOOR"
})

--------------------------------------------------------------------------
-- Configure all PLATFORM colliders
harbour:configurePrefabFlagList("models/boat.fbx/Prefab/harbour/boatPart/bateau", { "PLATFORM" })
harbour:configurePrefabFlagList("models/boat.fbx/Prefab/harbour/rowingPart/bateau", { "PLATFORM" })
harbour:configurePrefabFlagList("models/boat.fbx/Prefab/harbour/boatStaticPart/bateau", { "PLATFORM" })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/dockPart", { "PLATFORM" })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/pontonPart", { "PLATFORM" })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/rampPart", { "PLATFORM" })
harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/dockPart/TerrainDock", { DataType = "COMP_RIGID_BODY", Mass = 0 })
harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/pontonPart/TerrainPonton", { DataType = "COMP_RIGID_BODY", Mass = 0 })
harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/rampPart/TerrainRamp", { DataType = "COMP_RIGID_BODY", Mass = 0 })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/dockPart/TerrainDock", { "TERRAIN" })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/pontonPart/TerrainPonton", { "TERRAIN" })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/rampPart/TerrainRamp", { "TERRAIN" })
